api

package
v0.0.0-...-8452b8d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 24, 2014 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CustomPodDeploymentStrategy

type CustomPodDeploymentStrategy struct {
	Image       string       `json:"image,omitempty" yaml:"image,omitempty"`
	Environment []api.EnvVar `json:"environment,omitempty" yaml:"environment,omitempty"`
}

CustomPodDeploymentStrategy describes a deployment carried out by a custom pod.

type Deployment

type Deployment struct {
	api.JSONBase       `json:",inline" yaml:",inline"`
	Labels             map[string]string              `json:"labels,omitempty" yaml:"labels,omitempty"`
	Strategy           DeploymentStrategy             `json:"strategy,omitempty" yaml:"strategy,omitempty"`
	ControllerTemplate api.ReplicationControllerState `json:"controllerTemplate,omitempty" yaml:"controllerTemplate,omitempty"`
	State              DeploymentState                `json:"state,omitempty" yaml:"state,omitempty"`
	ConfigID           string                         `json:"configId,omitempty" yaml:"configId,omitempty"`
}

A Deployment represents a single unique realization of a DeploymentConfig.

func (*Deployment) IsAnAPIObject

func (*Deployment) IsAnAPIObject()

type DeploymentConfig

type DeploymentConfig struct {
	api.JSONBase  `json:",inline" yaml:",inline"`
	Labels        map[string]string              `json:"labels,omitempty" yaml:"labels,omitempty"`
	TriggerPolicy DeploymentTriggerPolicy        `json:"triggerPolicy,omitempty" yaml:"triggerPolicy,omitempty"`
	Template      DeploymentTemplate             `json:"template,omitempty" yaml:"template,omitempty"`
	CurrentState  api.ReplicationControllerState `json:"currentState" yaml:"currentState,omitempty"`
}

DeploymentConfig represents a configuration for a single deployment of a replication controller: what the template for the deployment, how new deployments are triggered, what the current deployed state is.

func (*DeploymentConfig) IsAnAPIObject

func (*DeploymentConfig) IsAnAPIObject()

type DeploymentConfigList

type DeploymentConfigList struct {
	api.JSONBase `json:",inline" yaml:",inline"`
	Items        []DeploymentConfig `json:"items,omitempty" yaml:"items,omitempty"`
}

A DeploymentConfigList is a collection of deployment configs

func (*DeploymentConfigList) IsAnAPIObject

func (*DeploymentConfigList) IsAnAPIObject()

type DeploymentList

type DeploymentList struct {
	api.JSONBase `json:",inline" yaml:",inline"`
	Items        []Deployment `json:"items,omitempty" yaml:"items,omitempty"`
}

A DeploymentList is a collection of deployments.

func (*DeploymentList) IsAnAPIObject

func (*DeploymentList) IsAnAPIObject()

type DeploymentState

type DeploymentState string

DeploymentState decribes the possible states a Deployment can be in.

const (
	DeploymentNew      DeploymentState = "new"
	DeploymentPending  DeploymentState = "pending"
	DeploymentRunning  DeploymentState = "running"
	DeploymentComplete DeploymentState = "complete"
	DeploymentFailed   DeploymentState = "failed"
)

type DeploymentStrategy

type DeploymentStrategy struct {
	Type      string                       `json:"type,omitempty" yaml:"type,omitempty"`
	CustomPod *CustomPodDeploymentStrategy `json:"customPod,omitempty" yaml:"customPod,omitempty"`
}

DeploymentStrategy describes how to perform a deployment.

type DeploymentTemplate

type DeploymentTemplate struct {
	Strategy           DeploymentStrategy             `json:"strategy,omitempty" yaml:"strategy,omitempty"`
	ControllerTemplate api.ReplicationControllerState `json:"controllerTemplate,omitempty" yaml:"controllerTemplate,omitempty"`
}

DeploymentTemplate contains all the necessary information to create a Deployment from a DeploymentStrategy.

type DeploymentTriggerPolicy

type DeploymentTriggerPolicy struct {
	Type DeploymentTriggerType `json:"type,omitempty" yaml:"type,omitempty"`
}

DeploymentTriggerPolicy describes the possible triggers that result in a new Deployment.

type DeploymentTriggerType

type DeploymentTriggerType string
const (
	DeploymentTriggerOnImageChange  DeploymentTriggerType = "image-change"
	DeploymentTriggerOnConfigChange DeploymentTriggerType = "config-change"
	DeploymentTriggerManual         DeploymentTriggerType = "manual"
)

Directories

Path Synopsis

Jump to